# 2.16 TOUCH 模块API手册



## 前言

### 概述

本文档主要介绍machine模块下的TOUCH类API。

### 读者对象

本文档（本指南）主要适用于以下人员：

- 技术支持工程师
- 软件开发工程师

### 缩略词定义

| 简称 | 说明 |
| ---- | ---- |
| | |

### 修订记录

| 文档版本号 | 修改说明 | 修改者     | 日期       |
| ---------- | -------- | ---------- | ---------- |
| V1.0       | 初版     | 软件部      | 2024-04-20 |
| V2.0       | 增加旋转支持 | xel | 20224-07-22 |

## 1. 概述

触摸模块基于rtt的触摸框架，支持单点多点电容触摸屏、电阻触摸屏。

## 2. API描述

TOUCH类位于machine模块下

### 示例

```python
from machine import TOUCH
# 实例化TOUCH设备0
tp = TOUCH(0)
# 获取TOUCH数据
p = tp.read()
print(p)
# print(p[0].x)
# print(p[0].y)
# print(p[0].event)
```

### 构造函数

```python
touch = TOUCH(index, rotation)
```

【参数】

- index: TOUCH设备号，取值:[0,9]，实际取决于有几个触摸设备
- rotation: 面板输出坐标与屏幕坐标旋转，取值[0-3]，具体定义参考[坐标旋转](#42-坐标旋转)

### read

```python
TOUCH.read([count])
```

获取触摸数据

【参数】

- count: 最多读取多少个触摸点，取值:[0:10]，默认为0，读取全部触摸点

【返回值】

返回触摸点数据，类型为tuple，([tp[,tp...]])，每个tp都是一个touch_info类

### deinit

```python
TOUCH.deinit()
```

释放TOUCH资源

【参数】

无

【返回值】

无

## 3. TOUCH_INFO 类

TOUCH_INFO类存储了触摸点的信息，用户可通过相关属性(只读)去访问

- event，事件码，具体参考[触摸事件](#41-触摸事件)
- track_id，触点id，用于多点触摸
- width，触点width
- x，触点x坐标
- y，触点y坐标
- timestamp，触点时间辍

## 4. 常量

### 4.1 触摸事件

- EVENT_NONE: 无
- EVENT_UP: 触摸按下之后抬起
- EVENT_DOWN: 触摸按下开始
- EVENT_MOVE： 触摸按下之后移动

### 4.2 坐标旋转

- ROTATE_0: 坐标不旋转
- ROTATE_90: 坐标旋转90度
- ROTATE_180: 坐标选择180度
- ROTATE_270: 坐标选择270度
